Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEd Merks2017-02-27 10:11:47 +0000
committerEd Merks2017-02-27 10:11:47 +0000
commitba19b9e24f1959692c97b3a4dc5ce91a32936d07 (patch)
tree25078787fcdbbcb5dd53206c398f87e88b005b75 /plugins/org.eclipse.emf.common.ui
parent2d61310cf5083ae3c2e2c080c674e6c8c277d652 (diff)
downloadorg.eclipse.emf-ba19b9e24f1959692c97b3a4dc5ce91a32936d07.tar.gz
org.eclipse.emf-ba19b9e24f1959692c97b3a4dc5ce91a32936d07.tar.xz
org.eclipse.emf-ba19b9e24f1959692c97b3a4dc5ce91a32936d07.zip
[496972] On Eclipse Neon, create markers on an old XMI file with an
updated Xcore model slow eclipse a lot
Diffstat (limited to 'plugins/org.eclipse.emf.common.ui')
-rw-r--r--plugins/org.eclipse.emf.common.ui/src/org/eclipse/emf/common/ui/MarkerHelper.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/plugins/org.eclipse.emf.common.ui/src/org/eclipse/emf/common/ui/MarkerHelper.java b/plugins/org.eclipse.emf.common.ui/src/org/eclipse/emf/common/ui/MarkerHelper.java
index bec5d66fe..c22adbd59 100644
--- a/plugins/org.eclipse.emf.common.ui/src/org/eclipse/emf/common/ui/MarkerHelper.java
+++ b/plugins/org.eclipse.emf.common.ui/src/org/eclipse/emf/common/ui/MarkerHelper.java
@@ -17,9 +17,9 @@ import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IMarker;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspace;
+import org.eclipse.core.resources.IWorkspaceRunnable;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.ICoreRunnable;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.Path;
import org.eclipse.ui.IEditorInput;
@@ -104,7 +104,7 @@ public class MarkerHelper
public void createMarkers(final Diagnostic diagnostic) throws CoreException
{
ResourcesPlugin.getWorkspace().run
- (new ICoreRunnable()
+ (new IWorkspaceRunnable()
{
public void run(IProgressMonitor monitor) throws CoreException
{
@@ -238,7 +238,7 @@ public class MarkerHelper
try
{
resource.getWorkspace().run
- (new ICoreRunnable()
+ (new IWorkspaceRunnable()
{
public void run(IProgressMonitor monitor) throws CoreException
{
@@ -340,7 +340,7 @@ public class MarkerHelper
/**
* {@link #deleteMarkers(Object) deletes} any markers associated with the resource of the given diagnostic and the {@link #createMarkers(Diagnostic) creates} new markers for it.
* All processing is done with as a single {@link IWorkspace#run(ICoreRunnable, IProgressMonitor) workspace operation}.
* @param diagnostic the diagnostic to process.
* @throws CoreException if creating markers results in a core exception.
* @since 2.13
@@ -348,7 +348,7 @@ public class MarkerHelper
public void updateMarkers(final Diagnostic diagnostic) throws CoreException
{
ResourcesPlugin.getWorkspace().run
- (new ICoreRunnable()
+ (new IWorkspaceRunnable()
{
public void run(IProgressMonitor monitor) throws CoreException
{
@@ -340,7 +340,7 @@ public class MarkerHelper
/**
* {@link #deleteMarkers(Object) deletes} any markers associated with the resource of the given diagnostic and the {@link #createMarkers(Diagnostic) creates} new markers for it.
- * All processing is done with as a single {@link IWorkspace#run(ICoreRunnable, IProgressMonitor) workspace operation}.
+ * All processing is done with as a single {@link IWorkspace#run(IWorkspaceRunnable, IProgressMonitor) workspace operation}.
* @param diagnostic the diagnostic to process.
* @throws CoreException if creating markers results in a core exception.

Back to the top